<?php


namespace App\Mobile\Synchronization\Controllers;

use App\Mobile\Synchronization\Resources\RouteResource;
use App\Mobile\Synchronization\Resources\RouteResourceUserLogado;
use App\Mobile\Synchronization\Resources\SyncBuscaClientMobileResource;
use App\Mobile\Synchronization\Resources\SyncAllClientsResource;
use App\Mobile\Synchronization\Resources\SyncPersonModalityClientResource;
use Freelabois\LaravelQuickstart\Extendables\CrudController;
use Illuminate\Support\Facades\Lang;
use Schaffen\Core\Person\Repositories\PersonModalityRepository;
use Schaffen\Financial\BillingRoute\Managers\RouteManager;
use Schaffen\Financial\BillingRoute\Managers\SalesmanRouteManager;
use Schaffen\Financial\BillingRoute\Repositories\RouteRepository;
use Schaffen\Financial\BillingRoute\Repositories\ClientRouteRepository;
use Illuminate\Http\Request;
use Schaffen\Financial\BillingRoute\Repositories\SalesmanRouteRepository;


class RouteController extends CrudController
{
    protected $resource = RouteResource::class;

    public function __construct(
        RouteManager          $manager,
        RouteRepository       $repository,
        SalesmanRouteManager  $salesman_route_manager,
        ClientRouteRepository $client_route_repository

    )
    {
        parent::__construct($manager, $repository);
        $this->client_route_repository = $client_route_repository;
        $this->salesman_route_manager = $salesman_route_manager;
    }

    public function index()
    {
        $user = auth()->user();
        return RouteResource::collection($this->salesman_route_manager->buscaRotasVendedor($user));
    }

    public function store()
    {
        throw new \Exception(Lang::get('exceptions.command.invalid'), 403);
    }

    public function update($id)
    {
        throw new \Exception(Lang::get('exceptions.command.invalid'), 403);
    }

    public function buscarCliente(Request $request)
    {
        $sanitized = $request->all();
        return SyncBuscaClientMobileResource::collection($this->manager->buscaCliente($sanitized));
    }

    public function todosClientesEmRota(Request $request)
    {
        $sanitized = $request->all();
        $per_page = $sanitized['per_page'] ?? 15;
        return SyncAllClientsResource::collection($this->client_route_repository->list([], ['person'], $per_page));
    }

    public function clientsAll(Request $request)
    {
        $sanitized = $request->all();
        $per_page = $sanitized['per_page'] ?? 15;
        $person_modality_repository = app()->make(PersonModalityRepository::class);
        return SyncPersonModalityClientResource::collection($person_modality_repository->list(['pem_fk_mdd_codigo' => 3], ['person'], $per_page));
    }

    public function rotaUsuarioLogado()
    {
        $values['pes_codigo'] = auth()->user()['usu_fk_pes_codigo'];
        return SyncAllClientsResource::collection($this->salesman_route_manager->getClientesEmRotaDoVendedor($values));
    }

}
