<?php

namespace App\Providers;


use App\Domain\Utils\Validations\IdentificationDocumentValidation;
use DateTime;
use Illuminate\Support\Facades\Event;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\ServiceProvider;


class AppServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     *
     * @return void
     */
    public function register()
    {
        //
    }

    /**
     * Bootstrap any application services.
     *
     * @return void
     */
    public function boot()
    {
        if (env('QUERY_LOGGER', false)) {
            Event::listen('Illuminate\Database\Events\QueryExecuted', function ($query) {
                foreach ($query->bindings as $i => $binding) {
                    if ($binding instanceof DateTime) {
                        $query->bindings[$i] = $binding->format('\'Y-m-d H:i:s\'');
                    } else {
                        if (is_string($binding)) {
                            $query->bindings[$i] = "'$binding'";
                        }
                    }
                }

                $debugged_query = vsprintf(str_replace(array('?'), array('\'%s\''), $query->sql), $query->bindings);
                if (!strpos($debugged_query, 'sql_loggers')) {
                    Log::info('io', ["query" => $debugged_query, "time" => $query->time]);
                }
            });
        }

        /** @var IdentificationDocumentValidation $documentValidationService */
        $documentValidationService = app()->make(IdentificationDocumentValidation::class);

        Validator::extend('identification', function ($attribute, $value, $parameters, $validator) use ($documentValidationService) {
            return $documentValidationService->validateCPF($value) || $documentValidationService->validateCNPJ($value);
        }, trans('validation.identification'));
    }
}
